summary refs log tree commit diff
path: root/synapse/config/__init__.py
diff options
context:
space:
mode:
authorOlivier Wilkinson (reivilibre) <olivier@librepush.net>2019-08-29 15:02:09 +0100
committerOlivier Wilkinson (reivilibre) <olivier@librepush.net>2019-08-29 15:02:09 +0100
commit60481031f2f1e43aaedc96a33441bfcf15262330 (patch)
treeb7f1e9e461e3034b1ca0fd75e6ea4ea185986cfb /synapse/config/__init__.py
parentCount total_events and total_event_bytes within the loop. (diff)
parentMerge branch 'develop' into rei/rss_target (diff)
downloadsynapse-60481031f2f1e43aaedc96a33441bfcf15262330.tar.xz
Merge branch 'rei/rss_target' into rei/rss_inc5 rei/rss_inc5
Diffstat (limited to 'synapse/config/__init__.py')
-rw-r--r--synapse/config/__init__.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/synapse/config/__init__.py b/synapse/config/__init__.py
index f2a5a41e92..1e76e9559d 100644
--- a/synapse/config/__init__.py
+++ b/synapse/config/__init__.py
@@ -13,8 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from ._base import ConfigError
+from ._base import ConfigError, find_config_files
 
 # export ConfigError if somebody does import *
 # this is largely a fudge to stop PEP8 moaning about the import
-__all__ = ["ConfigError"]
+__all__ = ["ConfigError", "find_config_files"]
@@ -13,8 +13,9 @@
 
-# export ConfigError if somebody does import *
+# export ConfigError and find_config_files if somebody does
+# import *
 # this is largely a fudge to stop PEP8 moaning about the import